BmrtExceptionHandler class

Constructors

BmrtExceptionHandler(MethodChannel channel)

Properties

hashCode → int
The hash code for this object.
no setterinherited
isUnhandledInterceptionActive → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

activateUnhandledInterception() → void
deactivateUnhandledInterception() → void
installGlobalErrorHandler([bool force = false]) → void
logException(dynamic exception, bool handled, [dynamic stackTrace]) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
syncWithOptions(BmrtLaunchOptions? launchOptions) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited