IOSLaunchOptions class

Bmrt launch options for iOS

Inheritance

Constructors

IOSLaunchOptions()

Properties

captureDeviceAndNetworkNames ↔ bool
getter/setter pairinherited
crashReport ↔ bool
Catch and report application crashes
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
killDetection ↔ bool
Detect abnormal termination (experimental)
getter/setter pair
maxNetworkBodySize ↔ int
The maximal size of network request/response body.
getter/setter pairinherited
monitorBluetoothStatus ↔ bool
Constantly monitor Bluetooth status
getter/setter pair
reportPrioritySelector ↔ bool
Allow user to modify priority when reporting manually
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
screenshotToReport ↔ bool
Screenshot key to trigger report
getter/setter pair
viewHierarchyEnabled ↔ bool
Enable View hierarchy capturing
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setDefaults() → void
override
toMap() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](String index) → dynamic
inherited
operator []=(String index, dynamic value) → void
inherited