BmrtNetworkEventImpl class

Inheritance

Constructors

BmrtNetworkEventImpl()

Properties

body ↔ String?
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
headers ↔ Map<String, dynamic>?
getter/setter pairinherited
method → String
no setteroverride
redirectUrl ↔ String?
getter/setter pairinherited
requestPayload ↔ String?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
no setteroverride
url ↔ String
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

augmentAndExtendOriginalEvent(dynamic originalEvent, BmrtNetworkEvent? e) → dynamic
Convert class instance denoting the network event into the raw event data to pass it back to the native layer
fromRawEvent(dynamic event) → BmrtNetworkEvent?
Convert raw event data received from the native layer into the class instance with proper fields